import React from 'react';

type HttpMethod = 'GET' | 'POST' | 'PUT' | 'DELETE';
type CredentialType = 'same-origin' | 'include' | 'omit';
type CacheType = 'default' | 'no-store' | 'reload' | 'no-cache' | 'force-cache' | 'only-if-cached';
type ModeType = 'same-origin' | 'cors' | 'navigate' | 'no-cors';

interface useFetchJsonAsTOptions<T> {
    url: string;
    method?: HttpMethod;
    headers?: {
        [key: string]: string;
    };
    credentials?: CredentialType;
    cache?: CacheType;
    mode?: ModeType;
}
interface AbortableFetchOptions {
    body?: string;
}
interface useFetchJsonAsTResultState<T> {
    state: useFetchJsonAsTState;
    error: unknown;
    data: T;
}
interface useFetchJsonAsTResponse<T> extends useFetchJsonAsTResultState<T> {
    fetchData: (options: AbortableFetchOptions) => void;
}
type useFetchJsonAsTState = "start" | "in-progress" | "error" | "success";
declare function useFetchJsonAsT<T>({ url, method, headers, credentials, cache, mode, }: useFetchJsonAsTOptions<T>): useFetchJsonAsTResponse<T>;

interface SettingsOptions<T> {
    children: React.ReactNode;
    fetchJsonOptions: useFetchJsonAsTOptions<T>;
    Error: ({ error }: {
        error: unknown;
    }) => React.ReactNode;
    Loading: () => React.ReactNode;
}
declare const SettingsProvider: <T>({ children, fetchJsonOptions, Loading, Error }: SettingsOptions<T>) => React.JSX.Element;

declare const useSettings: <T>() => T;

export { type AbortableFetchOptions, type CacheType, type CredentialType, type HttpMethod, type ModeType, SettingsProvider, useFetchJsonAsT, useSettings };
